Crate type_bridge_core_lib

Crate type_bridge_core_lib 

type-bridge-core-lib

Pure-Rust core library for type-bridge, providing a TypeQL AST, schema parser, query compiler, value coercer, and validation engine.

Modules

ModulePurpose
astTypeQL Abstract Syntax Tree — patterns, statements, clauses, and values
schemaSchema representation with entity / relation / attribute types and inheritance
validationSchema-aware query validation plus a custom validation-rule DSL
compilerCompiles an AST back into a TypeQL query string
query_parserParses a TypeQL query string into the AST
value_coercionCoerces raw values into TypeDB value-types and formats TypeQL literals
reserved_wordsTypeQL reserved-word detection
parserLow-level PEG grammar consumed by query_parser

Modules

ast
TypeQL Abstract Syntax Tree — patterns, statements, clauses, and values.
compiler
Compiles an AST back into a TypeQL query string. TypeQL query compiler — converts AST Clauses into TypeQL query strings.
parser
Low-level PEG grammar for TypeQL, consumed by query_parser. Winnow-based parser for TypeQL define blocks.
query_parser
Parses a TypeQL query string into the AST. Winnow-based parser for TypeQL data-manipulation queries.
reserved_words
TypeQL reserved-word detection. TypeQL reserved words — keywords that cannot be used as type or variable names.
schema
Schema representation with entity / relation / attribute types and inheritance.
validation
Schema-aware query validation plus a custom validation-rule DSL.
value_coercion
Coerces raw values into TypeDB value-types and formats TypeQL literals. Value coercion and formatting for TypeDB value types.