type-bridge-core-lib
Pure-Rust core library for type-bridge, providing a TypeQL AST, schema parser, query compiler, value coercer, and validation engine.
Modules
| Module | Purpose |
|---|---|
ast | TypeQL Abstract Syntax Tree — patterns, statements, clauses, and values |
schema | Schema representation with entity / relation / attribute types and inheritance |
validation | Schema-aware query validation plus a custom validation-rule DSL |
compiler | Compiles an AST back into a TypeQL query string |
query_parser | Parses a TypeQL query string into the AST |
value_coercion | Coerces raw values into TypeDB value-types and formats TypeQL literals |
reserved_words | TypeQL reserved-word detection |
parser | Low-level PEG grammar consumed by query_parser |
Modules
- ast
- TypeQL Abstract Syntax Tree — patterns, statements, clauses, and values.
- compiler
- Compiles an AST back into a TypeQL query string.
TypeQL query compiler — converts AST
Clauses into TypeQL query strings. - parser
- Low-level PEG grammar for TypeQL, consumed by
query_parser. Winnow-based parser for TypeQLdefineblocks. - query_
parser - Parses a TypeQL query string into the AST. Winnow-based parser for TypeQL data-manipulation queries.
- reserved_
words - TypeQL reserved-word detection. TypeQL reserved words — keywords that cannot be used as type or variable names.
- schema
- Schema representation with entity / relation / attribute types and inheritance.
- validation
- Schema-aware query validation plus a custom validation-rule DSL.
- value_
coercion - Coerces raw values into TypeDB value-types and formats TypeQL literals. Value coercion and formatting for TypeDB value types.